# 333 reason

**Description:** Applies logical reasoning to analyze the problem. The "reason" stage (Logician) breaks down the task and develops rational conclusions or solution steps.

**Usage:** `333 reason`

This stage adds a structured, critical analysis of the problem to the session.
